// generated from rosidl_generator_c/resource/idl__type_support.c.em
// with input from service_msgs:msg/ServiceEventInfo.idl
// generated code does not contain a copyright notice

#include <string.h>

#include "service_msgs/msg/detail/service_event_info__functions.h"
#include "service_msgs/msg/detail/service_event_info__struct.h"
#include "rosidl_typesupport_interface/macros.h"
#include "service_msgs/msg/detail/service_event_info__type_support.h"

#ifdef __cplusplus
extern "C"
{
#endif

#ifdef __cplusplus
}
#endif
